# edzed

A library for building small automated systems, i.e. systems that
control outputs according to input values, system’s internal state, date and time.

What is in the package:

- classes for creating combinational and sequential blocks
- methods for building a circuit by connecting the blocks
- a simple event-driven zero-delay digital circuit simulator

What is not included:

The application code must connect the circuit's inputs
and outputs with the outside world.

## Documentation

Please read the [online documentation](https://edzed.readthedocs.io/en/latest/) for more information.
